@@ -21,7 +21,7 @@
 #===============================================================================
 
 
-__version__ = "1.04"
+__version__ = "1.05"
 __project_url__ = "https://github.com/amoffat/sh"
 
 
@@ -29,8 +29,9 @@ __project_url__ = "https://github.com/amoffat/sh"
 import platform
 
 if "windows" in platform.system().lower():
-    raise ImportError("sh 1.0 is currently only supported on linux and osx. \
-please install pbs 0.109 (http://pypi.python.org/pypi/pbs) for windows support.")
+    raise ImportError("sh %s is currently only supported on linux and osx. \
+please install pbs 0.110 (http://pypi.python.org/pypi/pbs) for windows \
+support." % __version__)
 
 
 
@@ -486,14 +487,16 @@ If you're using glob.glob(), please use sh.glob() instead." % self.path, stackle
             # we're passing a short arg as a kwarg, example:
             # cut(d="\t")
             if len(k) == 1:
-                processed_args.append("-"+k)
-                if v is not True: processed_args.append(self._format_arg(v))
+                if v is not False:
+                    processed_args.append("-"+k)
+                    if v is not True: processed_args.append(self._format_arg(v))
 
             # we're doing a long arg
             else:
                 k = k.replace("_", "-")
 
                 if v is True: processed_args.append("--"+k)
+                elif v is False: pass
                 else: processed_args.append("--%s=%s" % (k, self._format_arg(v)))
 
         return processed_args
@@ -1486,8 +1489,11 @@ class SelfWrapper(ModuleType):
         # nicely.  if i make these attributes dynamic lookups in
         # __getattr__, reload sometimes chokes in weird ways...
         for attr in ["__builtins__", "__doc__", "__name__", "__package__"]:
-            setattr(self, attr, getattr(self_module, attr))
+            setattr(self, attr, getattr(self_module, attr, None))
 
+        # python 3.2 (2.7 and 3.3 work fine) breaks on osx (not ubuntu)
+        # if we set this to None.  and 3.3 needs a value for __path__
+        self.__path__ = []
         self.self_module = self_module
         self.env = Environment(globals())
     
@@ -1519,7 +1525,7 @@ if __name__ == "__main__":
             else:
                 print("Couldn't find %s, skipping" % py_version.capitalize())
 
-        versions = ("2.6", "2.7", "3.1", "3.2")
+        versions = ("2.6", "2.7", "3.1", "3.2", "3.3")
         for version in versions: run_test(version)
 
     else:
